AsyncValidationIndicator constructor

AsyncValidationIndicator({
  1. Key? key,
  2. required CompanionPresenterMixin presenter,
  3. required String propertyName,
  4. String? text,
  5. double? height,
})

Initializes a new AsyncValidationIndicator.

Specify presenter and propertyName to create indicator for the specified property in the presenter. The propertyName should be used for the form field which handles input for the property.

Implementation

AsyncValidationIndicator({
  super.key,
  required CompanionPresenterMixin presenter,
  required String propertyName,
  this.text,
  this.height,
}) : _hasPendingAsyncValidationListener =
          presenter.getPropertyPendingAsyncValidationsListener(propertyName);