autovalidate property
If true, generating code set AutovalidateMode.onUserInteraction for
each FormFields' autovalidateMode named argument.
If false, the set value will be AutovalidateMode.disabled.
If null (default), autovalidate_by_default configuration option's
value will be used.
Default is null.
If you want to control per presenter (or Form) basis, set this property.
Else, if you want to control per your team or project basis, set
autovalidate_by_default configuration option and do not specify this
property.
When you want to control per field basis, specify autovalidateMode named
argument on form field factories.
In summary, priority is following:
- Form field fatrories'
autovalidateModearguments. - This
autovalidateproperty value. autovalidate_by_defaultconfiguration option.
Implementation
final bool? autovalidate;